pub struct Auth<S: Storage = LocalStorage> {
pub paths: DomainPaths,
pub storage: Arc<S>,
/* private fields */
}Fields
paths: DomainPathsstorage: Arc<S>Implementations
Sourceimpl<S: Storage + Send + Sync> Auth<S>
impl<S: Storage + Send + Sync> Auth<S>
pub fn new(paths: DomainPaths, storage: Arc<S>) -> Self
pub async fn login<T: HttpClient>( &self, http_client: &T, host: &Host, refresh_token: String, ) -> Res
Sourcepub async fn get_or_register_client<T: HttpClient>(
&self,
http_client: &T,
host: &Host,
redirect_uri: &str,
) -> Res<OAuthClient>
pub async fn get_or_register_client<T: HttpClient>( &self, http_client: &T, host: &Host, redirect_uri: &str, ) -> Res<OAuthClient>
Get a stored OAuth client_id for the host, or register a new one via DCR.
Sourcepub async fn login_oauth<T: HttpClient>(
&self,
http_client: &T,
host: &Host,
params: OAuthParams,
) -> Res
pub async fn login_oauth<T: HttpClient>( &self, http_client: &T, host: &Host, params: OAuthParams, ) -> Res
Login using OAuth 2.1 Authorization Code flow with PKCE.
Exchanges the authorization code for tokens, then fetches S3 credentials.
State / CSRF verification
This method does not verify the state parameter returned by the
Authorization Endpoint. The caller is responsible for comparing the
state value in the callback against the value generated by
random_state before calling this method (RFC 6749 10.12).
pub async fn get_credentials_or_refresh<T: HttpClient>( &self, http_client: &T, host: &Host, ) -> Res<Credentials>