DomainPaths

Struct DomainPaths 

pub struct DomainPaths { /* private fields */ }
Helper for getting paths. We heavily rely on where we put files, and this struct contains info of the directory structure .

Implementations

Source

impl DomainPaths

pub fn new(root_dir: PathBuf) -> Self

pub fn auth_host(&self, host: &Host) -> PathBuf

pub fn installed_manifest(&self, namespace: &Namespace, hash: &str) -> PathBuf

Path to the installed manifest.

Takes (namespace, hash) rather than &ManifestUri because the installed manifest may belong to either a remote-backed package (where a ManifestUri is available) or a local-only package (created via flow::create, where there is no bucket or origin). A local commit also produces a hash that has no remote counterpart yet.

pub fn installed_manifests_dir(&self, namespace: &Namespace) -> PathBuf

Directory for storing installed manifests

pub fn lineage(&self) -> PathBuf

Path to the lineage file

pub fn cached_manifest(&self, uri: &ManifestUri) -> PathBuf

Path to the manifest cached in semi-temporary directory

pub fn cached_manifests_dir(&self, bucket: &str) -> PathBuf

Directory for storing cached manifests for a bucket

pub fn objects_dir(&self) -> PathBuf

Directory for storing pristine hashed files

pub fn object(&self, hash: &[u8]) -> PathBuf

Path to the pristine hashed file

pub async fn scaffold_for_installing( &self, storage: &impl Storage, home: &Home, namespace: &Namespace, ) -> Res

pub async fn scaffold_for_caching( &self, storage: &impl Storage, bucket: &str, ) -> Res